==> nanoc-3.3.6.gem: test/extra/validators/test_links.rb <==
# encoding: utf-8

class Nanoc::Extra::Validators::LinksTest < MiniTest::Unit::TestCase

  include Nanoc::TestHelpers

  def test_is_external_href?
    # Create validator
    validator = Nanoc::Extra::Validators::Links.new(nil, nil)

    # Test
    assert  validator.send(:is_external_href?, 'http://example.com/')
    assert  validator.send(:is_external_href?, 'https://example.com/')
    assert  validator.send(:is_external_href?, 'mailto:bob@example.com')
    assert !validator.send(:is_external_href?, '../stuff')
    assert !validator.send(:is_external_href?, '/stuff')
  end

  def test_is_valid_internal_href?
    # Create files
    FileUtils.mkdir_p('output')
    FileUtils.mkdir_p('output/stuff')
    File.open('output/origin',     'w') { |io| io.write('hi') }
    File.open('output/foo',        'w') { |io| io.write('hi') }
    File.open('output/stuff/blah', 'w') { |io| io.write('hi') }

    # Create validator
    validator = Nanoc::Extra::Validators::Links.new('output', [ 'index.html' ])

    # Test
    assert validator.send(:is_valid_internal_href?, 'foo',         'output/origin')
    assert validator.send(:is_valid_internal_href?, 'origin',      'output/origin')
    assert validator.send(:is_valid_internal_href?, 'stuff/blah',  'output/origin')
    assert validator.send(:is_valid_internal_href?, '/foo',        'output/origin')
    assert validator.send(:is_valid_internal_href?, '/origin',     'output/origin')
    assert validator.send(:is_valid_internal_href?, '/stuff/blah', 'output/origin')
  end

  def test_is_valid_external_href?
    # Create validator
    validator = Nanoc::Extra::Validators::Links.new('output', [ 'index.html' ])
    validator.stubs(:fetch_http_status_for).returns(200)

    # Test
    assert validator.send(:is_valid_external_href?, 'http://example.com/')
    assert validator.send(:is_valid_external_href?, 'https://example.com/')
    assert validator.send(:is_valid_external_href?, 'foo://example.com/')
    refute validator.send(:is_valid_external_href?, 'http://example.com/">')
  end

  def test_fetch_http_status_for
    # Create validator
    validator = Nanoc::Extra::Validators::Links.new('output', [ 'index.html' ])

    # Test
    assert_equal 200, validator.send(:fetch_http_status_for, URI.parse('http://www.apple.com/'))
    assert_equal 200, validator.send(:fetch_http_status_for, URI.parse('https://www.apple.com/'))
    assert_equal 404, validator.send(:fetch_http_status_for, URI.parse('http://www.apple.com/sdfghgfdsdfgh'))
  end

end

==> nanoc-3.3.7.gem: test/extra/validators/test_links.rb <==
# encoding: utf-8

class Nanoc::Extra::Validators::LinksTest < MiniTest::Unit::TestCase

  include Nanoc::TestHelpers

  def test_is_external_href?
    # Create validator
    validator = Nanoc::Extra::Validators::Links.new(nil, nil)

    # Test
    assert  validator.send(:is_external_href?, 'http://example.com/')
    assert  validator.send(:is_external_href?, 'https://example.com/')
    assert  validator.send(:is_external_href?, 'mailto:bob@example.com')
    assert !validator.send(:is_external_href?, '../stuff')
    assert !validator.send(:is_external_href?, '/stuff')
  end

  def test_is_valid_internal_href?
    # Create files
    FileUtils.mkdir_p('output')
    FileUtils.mkdir_p('output/stuff')
    File.open('output/origin',     'w') { |io| io.write('hi') }
    File.open('output/foo',        'w') { |io| io.write('hi') }
    File.open('output/stuff/blah', 'w') { |io| io.write('hi') }

    # Create validator
    validator = Nanoc::Extra::Validators::Links.new('output', [ 'index.html' ])

    # Test
    assert validator.send(:is_valid_internal_href?, 'foo',         'output/origin')
    assert validator.send(:is_valid_internal_href?, 'origin',      'output/origin')
    assert validator.send(:is_valid_internal_href?, 'stuff/blah',  'output/origin')
    assert validator.send(:is_valid_internal_href?, '/foo',        'output/origin')
    assert validator.send(:is_valid_internal_href?, '/origin',     'output/origin')
    assert validator.send(:is_valid_internal_href?, '/stuff/blah', 'output/origin')
  end

  def test_is_valid_external_href?
    # Create validator
    validator = Nanoc::Extra::Validators::Links.new('output', [ 'index.html' ])
    validator.stubs(:fetch_http_status_for).returns(200)

    # Test
    assert validator.send(:is_valid_external_href?, 'http://example.com/')
    assert validator.send(:is_valid_external_href?, 'https://example.com/')
    assert validator.send(:is_valid_external_href?, 'foo://example.com/')
    refute validator.send(:is_valid_external_href?, 'http://example.com/">')
  end

  def test_fetch_http_status_for
    # Create validator
    validator = Nanoc::Extra::Validators::Links.new('output', [ 'index.html' ])

    # Test
    assert_equal 200, validator.send(:fetch_http_status_for, URI.parse('http://httpstat.us/200'))
    assert_equal 200, validator.send(:fetch_http_status_for, URI.parse('https://httpstat.us/200'))
    assert_equal 404, validator.send(:fetch_http_status_for, URI.parse('http://httpstat.us/404'))
  end

end
